==> hermes-6.0.2.40.tar.gz: hermes-6.0.2.40/app/services/batch_tasks/base.rb <==
module BatchTasks
  class Base

    def initialize(log_name = nil)
      @log_lines ||= []
      @log_name = log_name
    end 

    def log_lines
      @log_lines
    end 

    def update_log_lines(lines)
      @log_lines = lines
    end

    def log_is_csv?
      @log_name&.end_with?('.csv')
    end 

    def create_log_doc(tagset_id)
      message = "Creating a doc on the tagset #{tagset_id}"
      message = [message] if log_is_csv?

      add_to_log_file(message, true)

      doc = Doc.create(type: "file", title: @log_name, tagset_ids: tagset_id ? [tagset_id] : [])

      begin
        File.open(@log_name, 'r') do |file|
          doc.blob = file.read
        end
      rescue => e
        Rails.logger.error "Failed to read file: #{e.message}"
      end

      File.delete(@log_name) if File.exist?(@log_name)

      unless doc.save
        Rails.logger.error "Failed to save document: #{doc.errors.full_messages.join(', ')}"
      end
      doc
    end

    def add_to_log_file(line, force_flush = false)
      @log_lines ||= []
      @log_lines << line

      if @log_lines.length >= 1000 || force_flush
        if log_is_csv?
          CSV.open("./#{@log_name}", 'ab', col_sep: ";") do |csv|
            @log_lines.each do |line|
              csv << line
            end
          end
        else
          File.open(@log_name, "a:UTF-8") do |file|
            @log_lines.each do |content|
              file.write(content + "\n")
            end
          end
        end

        @log_lines.clear
      end
    end

    def print_time(time)
      time.utc.strftime('%Y-%m-%d-%H:%M:%S')
    end 

    private

    def enqueue_notifications(notif_hash, key)
      notification_nb = 0
    
      notif_hash.each do |housing_request_id, offer_ids|
        begin
          hr_attributes = Hermes::HousingRequest.where(id: housing_request_id).pluck(:id, :requester_firstname, :requester_lastname, :user_id)&.first
          next unless hr_attributes

          user = User.find(hr_attributes[3])
          user.notify(
            key: NOTIFICATION_KEYS[:user][key],
            channels: ['email'],
            datas: {
              first_name: hr_attributes[1],
              last_name: hr_attributes[2], 
              offer_ids: offer_ids
            },
            is_slow: true
          )
          
          notification_nb += 1
          add_to_log_file("Created notications for #{hr_attributes[0]} #{user.email} with offers: #{offer_ids.join(', ')}")
        rescue => exception
          add_to_log_file("housing_request_id : #{hr_attributes[0]} => #{exception}")
        end
      end 
    
      notification_nb
    end 
  end
end

==> hermes-6.0.2.45.tar.gz: hermes-6.0.2.45/app/services/batch_tasks/base.rb <==
module BatchTasks
  class Base

    def initialize(log_name = nil)
      @log_lines ||= []
      @log_name = log_name
    end 

    def log_lines
      @log_lines
    end 

    def update_log_lines(lines)
      @log_lines = lines
    end

    def log_is_csv?
      @log_name&.end_with?('.csv')
    end 

    def create_log_doc(tagset_id)
      message = "#{Time.now} Creating a doc on the tagset #{tagset_id}"
      message = [message] if log_is_csv?

      add_to_log_file(message, true)

      doc = Doc.create(type: "file", title: @log_name, tagset_ids: tagset_id ? [tagset_id] : [])

      begin
        File.open(@log_name, 'r') do |file|
          doc.blob = file.read
        end
      rescue => e
        Rails.logger.error "Failed to read file: #{e.message}"
      end

      File.delete(@log_name) if File.exist?(@log_name)

      unless doc.save
        Rails.logger.error "Failed to save document: #{doc.errors.full_messages.join(', ')}"
      end
      doc
    end

    def add_to_log_file(line, force_flush = false)
      @log_lines ||= []
      @log_lines << line

      if @log_lines.length >= 1000 || force_flush
        if log_is_csv?
          CSV.open("./#{@log_name}", 'ab', col_sep: ";") do |csv|
            @log_lines.each do |line|
              csv << line
            end
          end
        else
          File.open(@log_name, "a:UTF-8") do |file|
            @log_lines.each do |content|
              file.write(content + "\n")
            end
          end
        end

        @log_lines.clear
      end
    end

    def print_time(time)
      time.utc.strftime('%Y-%m-%d-%H:%M:%S')
    end 

    private

    def enqueue_notifications(notif_hash, key)
      notification_nb = 0
    
      notif_hash.each do |housing_request_id, offer_ids|
        begin
          hr_attributes = Hermes::HousingRequest.where(id: housing_request_id).pluck(:id, :requester_firstname, :requester_lastname, :user_id)&.first
          next unless hr_attributes

          user = User.find(hr_attributes[3])
          user.notify(
            key: NOTIFICATION_KEYS[:user][key],
            channels: ['email'],
            datas: {
              first_name: hr_attributes[1],
              last_name: hr_attributes[2], 
              offer_ids: offer_ids
            },
            is_slow: true
          )
          
          notification_nb += 1
          add_to_log_file("Created notications for #{hr_attributes[0]} #{user.email} with offers: #{offer_ids.join(', ')}")
        rescue => exception
          add_to_log_file("housing_request_id : #{hr_attributes[0]} => #{exception}")
        end
      end 
    
      notification_nb
    end 
  end
end
